@@ -418,6 +418,32 @@ H5Pclose <- function( h5plist ) {
 ##   invisible(res)
 ## }
 
+H5Pset_fapl_ros3 <- function( h5plist, s3credentials = NULL ) {
+  
+  if(.Platform$OS.type == "windows") {
+    stop("H5Pset_fapl_ros3() is only supported on non-windows operating systems.")
+  }
+  
+    ## this should really check it's a fapl, not just a plist.
+    h5checktype(h5plist, "plist")
+  
+    ## only do authentication if s3credentials are provided
+    if(!is.null(s3credentials)) {
+      auth <- TRUE
+      aws_region <- s3credentials[[1]]
+      access_key_id <- s3credentials[[2]]
+      secret_access_key <- s3credentials[[3]]
+    } else {
+      auth <- FALSE
+      aws_region <- access_key_id <- secret_access_key <- ""
+    }
+  
+    res <- .Call('_H5Pset_fapl_ros3', h5plist@ID, auth, 
+                 aws_region, access_key_id, secret_access_key, 
+                 PACKAGE = "rhdf5")
+    invisible(res)
+}
+
 ## H5Pset_fapl_stdio <- function( fapl_id ) {
 ##   # TODO: check type fapl
 ##   res <- .Call("_H5Pset_fapl_stdio", fapl_id, PACKAGE='rhdf5')
@@ -1032,21 +1058,19 @@ H5Pget_filter <- function( h5plist, idx ) {
 ##   invisible(res)
 ## }
 
-## H5Pset_shuffle <- function( plist_id ) {
-##   h5checktype(h5plist, "plist")
-##   res <- .Call("_H5Pset_shuffle", plist_id, PACKAGE='rhdf5')
-##   SEXP Rval = R_NilValue;
-##   invisible(res)
-## }
+H5Pset_shuffle <- function( h5plist ) {
+  h5checktypeAndPLC(h5plist, "H5P_DATASET_CREATE")
+  res <- .Call("_H5Pset_shuffle", h5plist@ID, PACKAGE='rhdf5')
+  invisible(res)
+}
 
-## H5Pset_szip <- function( plist, options_mask, pixels_per_block ) {
-##   h5checktype(h5plist, "plist")
-##   options_mask = as.integer(options_mask)
-##   pixels_per_block = as.integer(pixels_per_block)
-##   res <- .Call("_H5Pset_szip", plist, options_mask, pixels_per_block, PACKAGE='rhdf5')
-##   SEXP Rval = R_NilValue;
-##   invisible(res)
-## }
+H5Pset_szip <- function( h5plist, options_mask, pixels_per_block ) {
+  h5checktypeAndPLC(h5plist, "H5P_DATASET_CREATE")
+  options_mask = as.integer(options_mask)
+  pixels_per_block = as.integer(pixels_per_block)
+  res <- .Call("_H5Pset_szip", h5plist@ID, options_mask, pixels_per_block, PACKAGE='rhdf5')
+  invisible(res)
+}
 
 ## H5Pset_external <- function( plist, *name, offset, size ) {
 ##   h5checktype(h5plist, "plist")
@@ -1660,3 +1684,5 @@ H5Pclose_class <- function( h5plistclass ) {
   invisible(.Call("_H5Pclose_class", h5plistclass@ID, PACKAGE='rhdf5'))
 }
 
+
+
