@@ -73,7 +73,7 @@ h5createGroup <- function(file, group) {
   return(tid)
 }
 
-.createDCPL <- function(chunk, dims, level, fillValue, dtype) {
+.createDCPL <- function(chunk, dims, level, fillValue, dtype, filter, shuffle = FALSE) {
   
   dcpl <- H5Pcreate("H5P_DATASET_CREATE"); 
   if (length(chunk) > 0) {
@@ -95,10 +95,37 @@ h5createGroup <- function(file, group) {
     }
     H5Pset_fill_time( dcpl, "H5D_FILL_TIME_ALLOC" )
     H5Pset_chunk( dcpl, chunk)
-    if (level > 0) { 
-      H5Pset_deflate( dcpl, level ) 
+    
+    ## set the selected compression filter
+    filter <- toupper(filter)
+    if(!filter %in% c("GZIP", "ZLIB", "DEFLATE", 
+                      "SZIP",
+                      "BZIP2",
+                      "BLOSC_BLOSCLZ", "BLOSC_LZ4", "BLOSC_LZ4HC", "BLOSC_SNAPPY", "BLOSC_ZLIB", "BLOSC_ZSTD",
+                      "NONE")) {
+      warning("Filter not found, using default: ZLIB")
+      filter <- "ZLIB"
     }
+    
+    ## only use this shuffle if not using blosc filter
+    if(shuffle && !grepl("BLOSC", x = filter)) {
+      H5Pset_shuffle(dcpl)
+    }
+    
+    ## set the appropriate filter
+    if (filter %in% c("GZIP", "ZLIB", "DEFLATE")) { 
+      H5Pset_deflate( dcpl, level = level) 
+    } else if(filter == "SZIP") {
+      H5Pset_szip(dcpl, 1L, 32L)
+    } else if(filter == "BZIP2") {
+      H5Pset_bzip2( dcpl, level = level )
+    } else if (grepl(pattern = "BLOSC", x = filter)) {
+      method <- which(c("BLOSC_BLOSCLZ", "BLOSC_LZ4", "BLOSC_LZ4HC", "BLOSC_SNAPPY", "BLOSC_ZLIB", "BLOSC_ZSTD") == filter)
+      H5Pset_blosc(dcpl, method = method, h5tid = dtype, level = level, shuffle = shuffle )
+    }
+    
   }
+  
   if(!missing(fillValue)) {
     H5Pset_fill_value(dcpl, fillValue)
   }
@@ -111,14 +138,10 @@ h5createGroup <- function(file, group) {
 
 h5createDataset <- function(file, dataset, dims, maxdims = dims, 
                             storage.mode = "double", H5type = NULL, size = NULL,
-                            chunk = dims, level = 6, fillValue, showWarnings,
+                            chunk = dims, fillValue, 
+                            level = 6, filter = "gzip", shuffle = TRUE,
                             native = FALSE) {
   
-  if(!missing(showWarnings)) {
-    message("The 'showWarnings' argument has been deprecated and will be removed.\n",
-            "Use suppressMessages() and suppressWarnings() to limit messages printed to screen")
-  }
-  
   loc = h5checktypeOrOpenLoc(file, native = native)
   on.exit( h5closeitLoc(loc) )
   
@@ -155,8 +178,7 @@ h5createDataset <- function(file, dataset, dims, maxdims = dims,
         ## determine data type
         tid <- .setDataType(H5type, storage.mode, size)
         
-        ## dataset creation property list
-        dcpl <- .createDCPL(chunk, dims, level, fillValue, dtype = tid)
+        dcpl <- .createDCPL(chunk, dims, level, fillValue, dtype = tid, filter = filter, shuffle = shuffle)
         on.exit(H5Pclose(dcpl), add = TRUE)
         
         ## create dataspace
