@@ -72,7 +72,6 @@ SEXP _H5Dcreate( SEXP _loc_id, SEXP _name, SEXP _dtype_id, SEXP _space_id, SEXP
                            lcpl_id, dcpl_id, dapl_id );
     
     addHandle(hid);
-    //SEXP Rval = ScalarInteger(hid);
     SEXP Rval;
     PROTECT(Rval = HID_2_STRSXP(hid));
     UNPROTECT(1);
@@ -112,11 +111,11 @@ SEXP _H5Dclose( SEXP _dataset_id ) {
 
 /* hsize_t H5Dget_storage_size( hid_t dataset_id ) */
 SEXP _H5Dget_storage_size( SEXP _dataset_id ) {
-    //hid_t dataset_id = INTEGER(_dataset_id)[0];
+
     hid_t dataset_id = STRSXP_2_HID( _dataset_id );
     hsize_t size = H5Dget_storage_size( dataset_id );
-    
-    SEXP Rval;
+
+    SEXP Rval = ScalarInteger(0);
     if (size <= INT_MAX) {
         Rval = ScalarInteger(size);
     } else {
@@ -135,17 +134,28 @@ SEXP H5Dread_helper_INTEGER(hid_t dataset_id, hid_t file_space_id, hid_t mem_spa
     int b = H5Tget_size(dtype_id);
     H5T_sign_t sgn = H5Tget_sign(dtype_id);
     
-    int warn_NA = 0;
     int warn = 0;
+    int warn_overflow_64bit = 0;
     int warn_double = 0;
     
     /* 1-byte integers. Reading strategy is dependent on whether these 
      * are signed or unsigned (RAWSXP vs INTSXP) */
     if(b == 1) {
       void * buf;
+
       if(sgn == H5T_SGN_NONE) {
+        if (cpdType < 0) {
+          mem_type_id = H5T_NATIVE_UCHAR;
+        } else {
+          mem_type_id = H5Tcreate(H5T_COMPOUND, H5Tget_size(H5T_NATIVE_UCHAR));
+          herr_t status = H5Tinsert(mem_type_id, cpdField[0], 0, H5T_NATIVE_UCHAR);
+          for (int i=1; i<cpdNField; i++) {
+            hid_t mem_type_id2 = H5Tcreate(H5T_COMPOUND, H5Tget_size(H5T_NATIVE_UCHAR));
+            herr_t status = H5Tinsert(mem_type_id2, cpdField[i], 0, mem_type_id);
+            mem_type_id = mem_type_id2;
+          }
+        }
         
-        mem_type_id = H5T_NATIVE_UCHAR;
         if (length(_buf) == 0) {
           Rval = PROTECT(allocVector(RAWSXP, n));
           buf = RAW(Rval);
@@ -159,7 +169,17 @@ SEXP H5Dread_helper_INTEGER(hid_t dataset_id, hid_t file_space_id, hid_t mem_spa
         
       } else {
         
-        mem_type_id = H5T_NATIVE_INT32;
+        if (cpdType < 0) {
+          mem_type_id = H5T_NATIVE_INT32;
+        } else {
+          mem_type_id = H5Tcreate(H5T_COMPOUND, H5Tget_size(H5T_NATIVE_INT32));
+          herr_t status = H5Tinsert(mem_type_id, cpdField[0], 0, H5T_NATIVE_INT32);
+          for (int i=1; i<cpdNField; i++) {
+            hid_t mem_type_id2 = H5Tcreate(H5T_COMPOUND, H5Tget_size(H5T_NATIVE_INT32));
+            herr_t status = H5Tinsert(mem_type_id2, cpdField[i], 0, mem_type_id);
+            mem_type_id = mem_type_id2;
+          }
+        }
         if (length(_buf) == 0) {
           Rval = PROTECT(allocVector(INTSXP, n));
           buf = INTEGER(Rval);
@@ -202,12 +222,6 @@ SEXP H5Dread_helper_INTEGER(hid_t dataset_id, hid_t file_space_id, hid_t mem_spa
         if (native)
             PERMUTE(Rval, INTEGER, mem_space_id);
         
-        for (long long i=0; i<n; i++) {
-            if (((int *)buf)[i] == INT_MIN) {
-                warn_NA = 1;
-            }
-        }
-        //if (length(_buf) == 0 && n > 0) {
         if (length(_buf) == 0) {
             setAttrib(Rval, R_DimSymbol, Rdim);
         }
@@ -277,9 +291,6 @@ SEXP H5Dread_helper_INTEGER(hid_t dataset_id, hid_t file_space_id, hid_t mem_spa
                         ((int *)buf)[i] = INT_MIN;
                         warn = 1;
                     }
-                    if (((long long *)intbuf)[i] == INT_MIN) {
-                        warn_NA = 1;
-                    }
                 }
             } else if ((b == 8) & (sgn == H5T_SGN_NONE)) {
                 for (i=0; i<n; i++) {
@@ -347,11 +358,6 @@ SEXP H5Dread_helper_INTEGER(hid_t dataset_id, hid_t file_space_id, hid_t mem_spa
                     for (i=0; i<n; i++){
                         ((long long *)buf)[i] = ((long long *)intbuf)[i];
                     }
-                    for (i=0; i<n; i++) {
-                        if (((long long *)intbuf)[i] == LLONG_MIN) {
-                            warn_NA = 1;
-                        }
-                    }
                 } else if ((b == 8) & (sgn == H5T_SGN_NONE)) {
                     for (i=0; i<n; i++){
                         ((long long *)buf)[i] = ((unsigned long long *)intbuf)[i];
@@ -359,7 +365,7 @@ SEXP H5Dread_helper_INTEGER(hid_t dataset_id, hid_t file_space_id, hid_t mem_spa
                     for (i=0; i<n; i++) {
                         if (((unsigned long long *)intbuf)[i] > LLONG_MAX) {
                             ((long long *)buf)[i] = LLONG_MIN;
-                            warn = 1;
+                            warn_overflow_64bit = 1;
                         }
                     }
                 }
@@ -376,20 +382,12 @@ SEXP H5Dread_helper_INTEGER(hid_t dataset_id, hid_t file_space_id, hid_t mem_spa
     }
     }
     
-    if ((warn > 0) | (warn_NA > 0) | (warn_double > 0)) {
-        if (warn > 0) {
-            warning("NAs produced by integer overflow while converting 64-bit integer or unsigned 32-bit integer from HDF5 to a 32-bit integer in R.\nChoose bit64conversion='bit64' or bit64conversion='double' to avoid data loss and see the vignette 'rhdf5' for more details about 64-bit integers.");
-        } else {
-            if (warn_double > 0) {
-                warning("integer precision lost while converting 64-bit integer or unsigned 32-bit integer from HDF5 to double in R.\nChoose bit64conversion='bit64' to avoid data loss and see the vignette 'rhdf5' for more details about 64-bit integers.");
-            } else {
-                if (bit64conversion == 2) {
-                    warning("integer value -2^31 replaced by NA. See the section 'Large integer data types' in the 'rhdf5' vignette for more details.");
-                } else {
-                    warning("integer value -2^63 replaced NA. See the section 'Large integer data types' in the 'rhdf5' vignette for more details.");
-                }
-            }
-        }
+    if (warn > 0) {
+        warning("NAs produced by integer overflow while converting 64-bit integer or unsigned 32-bit integer from HDF5 to a 32-bit integer in R.\nChoose bit64conversion='bit64' or bit64conversion='double' to avoid data loss and see the vignette 'rhdf5' for more details about 64-bit integers.");
+    } else if (warn_overflow_64bit > 0) {
+        warning("NAs produced by integer overflow while converting unsigned 64-bit integer from HDF5 to signed 64-bit integer in R.");
+    } else if (warn_double > 0) {
+        warning("integer precision lost while converting 64-bit integer or unsigned 32-bit integer from HDF5 to double in R.\nChoose bit64conversion='bit64' to avoid data loss and see the vignette 'rhdf5' for more details about 64-bit integers.");
     }
     
     UNPROTECT( (length(_buf) == 0) + native );
@@ -519,7 +517,6 @@ SEXP H5Dread_helper_ENUM(hid_t dataset_id, hid_t file_space_id, hid_t mem_space_
             SET_STRING_ELT(levels, i, mkChar(st));
             herr_t status = H5Tenum_insert (enumtype, st, &i);
         }
-        UNPROTECT(1);
         
         if (cpdType < 0) {
             mem_type_id = enumtype;
@@ -562,7 +559,7 @@ SEXP H5Dread_helper_ENUM(hid_t dataset_id, hid_t file_space_id, hid_t mem_space_
             setAttrib(Rval, mkString("levels"), levels);
             setAttrib(Rval, R_ClassSymbol, mkString("factor"));
         }
-        UNPROTECT(native + (length(_buf) == 0));
+        UNPROTECT(native + (length(_buf) == 0) + 1);
     } else {
         double na = R_NaReal;
         Rval = PROTECT(allocVector(REALSXP, n));
