@@ -1,4 +1,5 @@
 #include "H5P.h"
+#include "H5pubconf.h"
 
 ////////////////////////////////////////////////////
 // General Property List Operations
@@ -682,14 +683,12 @@ SEXP _H5Pset_libver_bounds( SEXP _fapl_id, SEXP _libver_low, SEXP _libver_high )
     H5F_libver_t libver_low = INTEGER(_libver_low)[0];
     H5F_libver_t libver_high = INTEGER(_libver_high)[0];
     herr_t herr = H5Pset_libver_bounds(fapl_id, libver_low, libver_high);
-    //herr_t herr = H5Pset_libver_bounds(fapl_id, H5F_LIBVER_EARLIEST, H5F_LIBVER_LATEST);
     SEXP Rval = ScalarInteger(herr);
     return Rval;
 }
 
 /* /\* herr_t H5Pget_libver_bounds(hid_t fapl_id, H5F_libver_t * libver_low, H5F_libver_t * libver_high) *\/ */
 SEXP _H5Pget_libver_bounds( SEXP _fapl_id ) {
-   // hid_t fapl_id = INTEGER(_fapl_id)[0];
     hid_t fapl_id = STRSXP_2_HID( _fapl_id );
     H5F_libver_t libver_low;
     H5F_libver_t libver_high;
@@ -707,6 +706,43 @@ SEXP _H5Pget_libver_bounds( SEXP _fapl_id ) {
 }
 
 
+#ifdef H5_HAVE_ROS3_VFD
+/* herr_t H5Pset_fapl_ros3(hid_t fapl_id, H5FD_ros3_fapl_t *fa) */
+/* We pass the components of the H5FD_ros3_fapl_t separately */
+SEXP _H5Pset_fapl_ros3( SEXP _fapl_id, SEXP _authenticate, SEXP _aws_region, SEXP _access_key_id, SEXP _secret_access_key ) {
+    
+    hid_t fapl_id = STRSXP_2_HID( _fapl_id );
+    
+    // initialise in an non-authenticating fapl configuration 
+    H5FD_ros3_fapl_t fa = { 1, 0, "", "", "" };
+    int should_authenticate = INTEGER(_authenticate)[0];
+    const char *the_region = CHAR(STRING_ELT(_aws_region, 0));
+    const char *the_access_key_id = CHAR(STRING_ELT(_access_key_id, 0));
+    const char *the_secret_access_key = CHAR(STRING_ELT(_secret_access_key, 0));
+    
+    fa.authenticate = should_authenticate; /* 0 (FALSE) or 1 (TRUE) */
+    strncpy(fa.aws_region, the_region, H5FD_ROS3_MAX_REGION_LEN);
+    strncpy(fa.secret_id, the_access_key_id, H5FD_ROS3_MAX_SECRET_ID_LEN);
+    strncpy(fa.secret_key, the_secret_access_key, H5FD_ROS3_MAX_SECRET_KEY_LEN);
+    
+    herr_t herr = H5Pset_fapl_ros3(fapl_id, &fa);
+    SEXP Rval = ScalarInteger(herr);
+    return Rval;
+}
+#else
+SEXP _H5Pset_fapl_ros3( SEXP _fapl_id, SEXP _authenticate, SEXP _aws_region, SEXP _access_key_id, SEXP _secret_access_key ) {
+    
+    error("Rhdf5lib was not compiled with support for the S3 VFD\n");
+
+    herr_t herr = 0;
+    SEXP Rval = ScalarInteger(herr);
+    return Rval;
+}
+#endif
+
+
+
+
 ////////////////////////////////////////////////////
 // Group Creation Properties
 ////////////////////////////////////////////////////
@@ -1251,23 +1287,23 @@ SEXP _H5Pget_filter( SEXP _plist_id, SEXP _idx ) {
 /*   return Rval; */
 /* } */
 
-/* /\* herr_t H5Pset_shuffle(hid_t plist_id) *\/ */
-/* SEXP _H5Pset_shuffle( SEXP _plist_id ) { */
-/*   hid_t plist_id = INTEGER(_plist_id)[0]; */
-/*   herr_t herr = H5Pset_shuffle(hid_tplist_id); */
-/*   SEXP Rval = ScalarInteger(herr); */
-/*   return Rval; */
-/* } */
+/* herr_t H5Pset_shuffle(hid_t plist_id) */
+SEXP _H5Pset_shuffle( SEXP _plist_id ) { 
+  hid_t plist_id = STRSXP_2_HID( _plist_id );
+  herr_t herr = H5Pset_shuffle(plist_id);
+  SEXP Rval = ScalarInteger(herr);
+  return Rval;
+}
 
-/* /\* herr_t H5Pset_szip(hid_t plist, unsigned int options_mask, unsigned int pixels_per_block) *\/ */
-/* SEXP _H5Pset_szip( SEXP _plist, SEXP _options_mask, SEXP _pixels_per_block ) { */
-/*   hid_t plist = INTEGER(_plist)[0]; */
-/*   unsigned int options_mask = INTEGER(_options_mask)[0]; */
-/*   unsigned int pixels_per_block = INTEGER(_pixels_per_block)[0]; */
-/*   herr_t herr = H5Pset_szip(hid_tplist, unsigned intoptions_mask, unsigned intpixels_per_block); */
-/*   SEXP Rval = ScalarInteger(herr); */
-/*   return Rval; */
-/* } */
+/* herr_t H5Pset_szip(hid_t plist, unsigned int options_mask, unsigned int pixels_per_block) *\/ */
+SEXP _H5Pset_szip( SEXP _plist_id, SEXP _options_mask, SEXP _pixels_per_block ) {
+  hid_t plist_id = STRSXP_2_HID( _plist_id );
+  unsigned int options_mask = INTEGER(_options_mask)[0];
+  unsigned int pixels_per_block = INTEGER(_pixels_per_block)[0];
+  herr_t herr = H5Pset_szip(plist_id, options_mask, pixels_per_block);
+  SEXP Rval = ScalarInteger(herr);
+  return Rval;
+} 
 
 /* /\* herr_t H5Pset_external(hid_t plist, const char *name, off_t offset, hsize_t size) *\/ */
 /* SEXP _H5Pset_external( SEXP _plist, SEXP _*name, SEXP _offset, SEXP _size ) { */
@@ -1981,3 +2017,4 @@ SEXP _H5Pclose_class( SEXP _class ) {
     return Rval;
 }
 
+
