@@ -6,7 +6,7 @@
 #include <R_ext/Rdynload.h>
 #include <R_ext/Error.h>
 #include "myhdf5.h"
-#include "H5constants.h"
+//#include "H5constants.h"
 #include "HandleList.h"
 
 ////////////////////////////////////////////////////
@@ -92,6 +92,7 @@ SEXP _H5Pclose( SEXP _plist );
 /* SEXP _H5Pget_small_data_block_size( SEXP _fapl_id, SEXP _size ); */
 SEXP _H5Pset_libver_bounds( SEXP _fapl_id, SEXP _libver_low, SEXP _libver_high );
 SEXP _H5Pget_libver_bounds( SEXP _fapl_id );
+SEXP _H5Pset_fapl_ros3( SEXP _fapl_id, SEXP _authenticate, SEXP _aws_region, SEXP _access_key_id, SEXP _secret_acces_key );
 
 ////////////////////////////////////////////////////
 // Group Creation Properties
@@ -158,8 +159,8 @@ SEXP _H5Pget_filter( SEXP _plist_id, SEXP _idx );
 /* SEXP _H5Pset_fletcher32( SEXP _plist_id ); */
 /* SEXP _H5Pset_nbit( SEXP _plist_id ); */
 /* SEXP _H5Pset_scaleoffset( SEXP _plist_id, SEXP _scale_type, SEXP _scale_factor ); */
-/* SEXP _H5Pset_shuffle( SEXP _plist_id ); */
-/* SEXP _H5Pset_szip( SEXP _plist, SEXP _options_mask, SEXP _pixels_per_block ); */
+SEXP _H5Pset_shuffle( SEXP _plist_id );
+SEXP _H5Pset_szip( SEXP _plist, SEXP _options_mask, SEXP _pixels_per_block );
 /* SEXP _H5Pset_external( SEXP _plist, SEXP _*name, SEXP _offset, SEXP _size ); */
 /* SEXP _H5Pget_external_count( SEXP _plist ); */
 /* SEXP _H5Pget_external( SEXP _plist, SEXP _idx, SEXP _name_size, SEXP _*name, SEXP _*offset, SEXP _*size ); */
@@ -257,4 +258,7 @@ SEXP _H5Pequal( SEXP _id1, SEXP _id2 );
 /* SEXP _H5Punregister( SEXP _class, SEXP _name ); */
 SEXP _H5Pclose_class( SEXP _class );
 
+/* Experimental LZ4 filter */
+SEXP _H5Pset_lz4( SEXP _plist_id );
+
 #endif
