@@ -11,5 +11,7 @@
 SEXP _H5Tcopy( SEXP _dtype_id );
 SEXP _H5Tset_size( SEXP _dtype_id, SEXP _size );
 SEXP _H5Tget_size( SEXP _dtype_id );
+SEXP _H5Tset_strpad( SEXP _dtype_id, SEXP _strpad );
+SEXP _H5Tget_strpad( SEXP _dtype_id );
 
 #endif
