@@ -23,6 +23,7 @@
 #include "h5writeDataFrame.h"
 #include "printdatatype.h"
 #include "h5testLock.h"
+#include "external_filters.h"
 
 SEXP _H5open(void);
 SEXP _H5close(void);
@@ -53,12 +54,12 @@ static R_CallMethodDef libraryRCalls[] = {
   {"_H5Dget_type", (DL_FUNC) &_H5Dget_type, 1},
   {"_H5Dget_create_plist", (DL_FUNC) &_H5Dget_create_plist, 1},
   {"_H5Dget_space", (DL_FUNC) &_H5Dget_space, 1},
-  {"_H5Dget_storage_size", (DL_FUNC) &_H5Dget_space, 1},
+  {"_H5Dget_storage_size", (DL_FUNC) &_H5Dget_storage_size, 1},
   {"_H5Dread", (DL_FUNC) &_H5Dread, 8},
   {"_H5Dwrite", (DL_FUNC) &_H5Dwrite, 5},
   {"_H5Dset_extent", (DL_FUNC) &_H5Dset_extent, 2},
   {"_H5Fcreate", (DL_FUNC) &_H5Fcreate, 4},
-  {"_H5Fopen", (DL_FUNC) &_H5Fopen, 2},
+  {"_H5Fopen", (DL_FUNC) &_H5Fopen, 3},
   {"_H5Freopen", (DL_FUNC) &_H5Freopen, 1},
   {"_H5Fclose", (DL_FUNC) &_H5Fclose, 1},
   {"_H5Fflush", (DL_FUNC) &_H5Fflush, 2},
@@ -176,6 +177,7 @@ static R_CallMethodDef libraryRCalls[] = {
   /* {"_H5Pget_small_data_block_size", (DL_FUNC) &_H5Pget_small_data_block_size, 2}, */
   {"_H5Pset_libver_bounds", (DL_FUNC) &_H5Pset_libver_bounds, 3},
   {"_H5Pget_libver_bounds", (DL_FUNC) &_H5Pget_libver_bounds, 1},
+  {"_H5Pset_fapl_ros3", (DL_FUNC) &_H5Pset_fapl_ros3, 5},
   /* {"_H5Pset_local_heap_size_hint", (DL_FUNC) &_H5Pset_local_heap_size_hint, 2}, */
   /* {"_H5Pget_local_heap_size_hint", (DL_FUNC) &_H5Pget_local_heap_size_hint, 2}, */
   /* {"_H5Pset_link_creation_order", (DL_FUNC) &_H5Pset_link_creation_order, 2}, */
@@ -222,8 +224,8 @@ static R_CallMethodDef libraryRCalls[] = {
   /* {"_H5Pset_fletcher32", (DL_FUNC) &_H5Pset_fletcher32, 1}, */
   /* {"_H5Pset_nbit", (DL_FUNC) &_H5Pset_nbit, 1}, */
   /* {"_H5Pset_scaleoffset", (DL_FUNC) &_H5Pset_scaleoffset, 3}, */
-  /* {"_H5Pset_shuffle", (DL_FUNC) &_H5Pset_shuffle, 1}, */
-  /* {"_H5Pset_szip", (DL_FUNC) &_H5Pset_szip, 3}, */
+  {"_H5Pset_shuffle", (DL_FUNC) &_H5Pset_shuffle, 1},
+  {"_H5Pset_szip", (DL_FUNC) &_H5Pset_szip, 3},
   /* {"_H5Pset_external", (DL_FUNC) &_H5Pset_external, 4}, */
   /* {"_H5Pget_external_count", (DL_FUNC) &_H5Pget_external_count, 1}, */
   /* {"_H5Pget_external", (DL_FUNC) &_H5Pget_external, 6}, */
@@ -304,6 +306,12 @@ static R_CallMethodDef libraryRCalls[] = {
   {"_h5fileLock", (DL_FUNC) &_h5fileLock, 1},
   {"_H5Sselect_cols", (DL_FUNC) &_H5Sselect_cols, 5},
   {"_h5listOpenObjects", (DL_FUNC) &_h5listOpenObjects, 1},
+#ifdef _H5P_filters
+  //{"_H5Pset_lzf", (DL_FUNC) &_H5Pset_lzf, 1},
+  //{"_H5Pset_lz4", (DL_FUNC) &_H5Pset_lz4, 1},
+  {"_H5Pset_bzip2", (DL_FUNC) &_H5Pset_bzip2, 2},
+  {"_H5Pset_blosc", (DL_FUNC) &_H5Pset_blosc, 6},
+#endif
   {NULL, NULL, 0}
 };
 
